vdoc package | vdoc 0.19.0 documentation

Skip to content

# vdoc package

## Subpackages

- vdoc.api package
  - Subpackages
    - vdoc.api.dependencies package
      - Submodules
      - vdoc.api.dependencies.auth module
      - Module contents
    - vdoc.api.routes package
      - Submodules
      - vdoc.api.routes.plugins module
      - vdoc.api.routes.project_categories module
      - vdoc.api.routes.projects module
      - vdoc.api.routes.version module
      - Module contents
  - Submodules
  - vdoc.api.lifespan module
    - `routes_loader_lifespan()`
  - Module contents
    - `create_app()`
- vdoc.cli package
  - Submodules
  - vdoc.cli.main module
    - `LogLevel`
    - `check_for_default_credentials()`
    - `print_version()`
  - vdoc.cli.run module
  - Module contents
- vdoc.exceptions package
  - Module contents
    - `InvalidCredentials`
    - `InvalidProjectName`
    - `InvalidVersion`
    - `ProjectNotFound`
    - `ProjectVersionAlreadyExists`
    - `ProjectVersionNotFound`
    - `UploadedFileInvalid`
    - `VDocException`
- vdoc.methods package
  - Subpackages
    - vdoc.methods.api package
      - Submodules
      - vdoc.methods.api.project_categories module
      - vdoc.methods.api.projects module
      - Module contents
    - vdoc.methods.cli package
      - Submodules
      - vdoc.methods.cli.cli_run_method module
      - Module contents
  - Module contents
- vdoc.models package
  - Subpackages
    - vdoc.models.plugins package
      - Submodules
      - vdoc.models.plugins.base module
      - vdoc.models.plugins.footer module
      - vdoc.models.plugins.orama module
      - vdoc.models.plugins.theme module
      - Module contents
  - Submodules
  - vdoc.models.project module
    - `Project`
  - vdoc.models.project_category module
    - `ProjectCategory`
  - Module contents
- vdoc.settings package
  - Module contents
    - `VDocSettings`

## Submodules

## vdoc.constants module

Contains all constant values.

## Module contents

Multi version documentation hosting.

vdoc.get_app_name()

  Returns the human-readable and prettified name of the application.

  Return type:

    `str`

  Returns:

    The name of the application.

vdoc.get_app_version()

  Returns the version of the application.

  Return type:

    `str`

  Returns:

    The version of the application.

vdoc
vdoc.api package